@@ -1,8 +1,8 @@
 context("testing util functions")
 
 test_that("noisy_xor works as expected", {
-  expect_true(stagedtrees:::noisy_xor(c(-1,-1), 0) == 1)
-  expect_true(stagedtrees:::noisy_xor(c(-1,-1,-1), 0) == -1)
+  expect_true(stagedtrees:::noisy_xor(c(-1, -1), 0) == 1)
+  expect_true(stagedtrees:::noisy_xor(c(-1, -1, -1), 0) == -1)
   expect_true(stagedtrees:::noisy_xor(c(-1, 1), 0) == -1)
   expect_true(stagedtrees:::noisy_xor(c(1, -1), 0) == -1)
 })
@@ -14,9 +14,9 @@ test_that("new_lable produce a new label", {
 
 test_that("uni_idx works as expected", {
   expect_silent(ui <-
-                  stagedtrees:::uni_idx(list(
-                    A = c(1, 2, 3), B = c(1, 2, 3)
-                  )))
+    stagedtrees:::uni_idx(list(
+      A = c(1, 2, 3), B = c(1, 2, 3)
+    )))
   expect_true(all(ui$A == c("A:1", "A:2", "A:3")))
 })
 
@@ -39,9 +39,9 @@ test_that("lp(x,x) is = 0", {
   replicate(10, {
     x <- runif(10, min = 1, max = 2)
     x <- x / sum(x)
-    
+
     p <- rbinom(1, 5, 0.2) + 1
-    expect_equal(lp(!!x,!!x, p = !!p), 0)
+    expect_equal(lp(!!x, !!x, p = !!p), 0)
   })
 })
 
@@ -49,9 +49,9 @@ test_that("ry(x,x) is = 0", {
   replicate(10, {
     x <- runif(10, min = 1, max = 2)
     x <- x / sum(x)
-    
+
     alpha <- runif(1, min = 1.1, max = 10)
-    expect_equal(ry(!!x,!!x, alpha = !!alpha), 0)
+    expect_equal(ry(!!x, !!x, alpha = !!alpha), 0)
   })
 })
 
@@ -59,8 +59,8 @@ test_that("kl(x,x) is = 0", {
   replicate(10, {
     x <- runif(10, min = 1, max = 2)
     x <- x / sum(x)
-    
-    expect_equal(kl(!!x,!!x), 0)
+
+    expect_equal(kl(!!x, !!x), 0)
   })
 })
 
@@ -68,8 +68,8 @@ test_that("tv(x,x) is = 0", {
   replicate(10, {
     x <- runif(10, min = 1, max = 2)
     x <- x / sum(x)
-    
-    expect_equal(tv(!!x,!!x), 0)
+
+    expect_equal(tv(!!x, !!x), 0)
   })
 })
 
@@ -77,8 +77,8 @@ test_that("hl(x,x) is = 0", {
   replicate(10, {
     x <- runif(10, min = 1, max = 2)
     x <- x / sum(x)
-    
-    expect_equal(hl(!!x,!!x), 0)
+
+    expect_equal(hl(!!x, !!x), 0)
   })
 })
 
@@ -86,11 +86,20 @@ test_that("bh(x,x) is = 0", {
   replicate(10, {
     x <- runif(10, min = 1, max = 2)
     x <- x / sum(x)
-    
+
     expect_equal(bh(!!x, !!x), 0)
   })
 })
 
+test_that("cd(x,x) is = 0", {
+  replicate(10, {
+    x <- runif(10, min = 1, max = 2)
+    x <- x / sum(x)
+    
+    expect_equal(cd(!!x, !!x), 0)
+  })
+})
+
 ################# positive
 
 
@@ -98,12 +107,12 @@ test_that("lp(x,y) is >= 0", {
   replicate(10, {
     x <- runif(10, min = 0:9, max = 1:10)
     x <- x / sum(x)
-    
+
     y <- x + runif(10, min = 1, max = 2)
     y <- y / sum(y)
-    
+
     p <- rbinom(1, 20, 0.2)
-    expect_gte(lp(!!x,!!y, p = !!p), 0)
+    expect_gte(lp(!!x, !!y, p = !!p), 0)
   })
 })
 
@@ -111,12 +120,12 @@ test_that("ry(x,y) is >= 0", {
   replicate(10, {
     x <- runif(10, min = 0:9, max = 1:10)
     x <- x / sum(x)
-    
+
     y <- x + runif(10, min = 1, max = 2)
     y <- y / sum(y)
-    
+
     alpha <- runif(1, min = 1, max = 10)
-    expect_gte(ry(!!x,!!y, alpha = !!alpha), 0)
+    expect_gte(ry(!!x, !!y, alpha = !!alpha), 0)
   })
 })
 
@@ -124,11 +133,11 @@ test_that("kl(x,y) is >= 0", {
   replicate(10, {
     x <- runif(10, min = 0:9, max = 1:10)
     x <- x / sum(x)
-    
+
     y <- x + runif(10, min = 1, max = 2)
     y <- y / sum(y)
-    
-    expect_gte(kl(!!x,!!y), 0)
+
+    expect_gte(kl(!!x, !!y), 0)
   })
 })
 
@@ -136,11 +145,11 @@ test_that("tv(x,y) is >= 0", {
   replicate(10, {
     x <- runif(10, min = 0:9, max = 1:10)
     x <- x / sum(x)
-    
+
     y <- x + runif(10, min = 1, max = 2)
     y <- y / sum(y)
-    
-    expect_gte(tv(!!x,!!y), 0)
+
+    expect_gte(tv(!!x, !!y), 0)
   })
 })
 
@@ -148,15 +157,27 @@ test_that("hl(x,y) is >= 0", {
   replicate(10, {
     x <- runif(10, min = 0:9, max = 1:10)
     x <- x / sum(x)
-    
+
     y <- x + runif(10, min = 1, max = 2)
     y <- y / sum(y)
-    
-    expect_gte(hl(!!x,!!y), 0)
+
+    expect_gte(hl(!!x, !!y), 0)
   })
 })
 
 test_that("bh(x,y) is >= 0", {
+  replicate(10, {
+    x <- runif(10, min = 0:9, max = 1:10)
+    x <- x / sum(x)
+
+    y <- x + runif(10, min = 1, max = 2)
+    y <- y / sum(y)
+
+    expect_gte(bh(!!x, !!y), 0)
+  })
+})
+
+test_that("cd(x,y) is >= 0", {
   replicate(10, {
     x <- runif(10, min = 0:9, max = 1:10)
     x <- x / sum(x)
@@ -164,7 +185,7 @@ test_that("bh(x,y) is >= 0", {
     y <- x + runif(10, min = 1, max = 2)
     y <- y / sum(y)
     
-    expect_gte(bh(!!x, !!y), 0)
+    expect_gte(cd(!!x, !!y), 0)
   })
 })
 
@@ -174,13 +195,15 @@ test_that("lp(x,y) is symmetric", {
   replicate(10, {
     x <- runif(10)
     x <- x / sum(x)
-    
+
     y <- runif(10)
     y <- y / sum(y)
-    
+
     p <- rbinom(1, 20, 0.2)
-    expect_equal(lp(!!x,!!y, p = !!p), 
-                 lp(!!y, !!x, p = !!p))
+    expect_equal(
+      lp(!!x, !!y, p = !!p),
+      lp(!!y, !!x, p = !!p)
+    )
   })
 })
 
@@ -188,13 +211,15 @@ test_that("ry(x,y) is symmetric", {
   replicate(10, {
     x <- runif(10)
     x <- x / sum(x)
-    
+
     y <- runif(10)
     y <- y / sum(y)
-    
+
     alpha <- runif(1, min = 1.1, max = 10)
-    expect_equal(ry(!!x,!!y, alpha = !!alpha), 
-                 ry(!!y,!!x, alpha = !!alpha))
+    expect_equal(
+      ry(!!x, !!y, alpha = !!alpha),
+      ry(!!y, !!x, alpha = !!alpha)
+    )
   })
 })
 
@@ -202,11 +227,11 @@ test_that("kl(x,y) is symmetric", {
   replicate(10, {
     x <- runif(10)
     x <- x / sum(x)
-    
+
     y <- runif(10)
     y <- y / sum(y)
-    
-    expect_equal(kl(!!x,!!y), kl(!!y,!!x))
+
+    expect_equal(kl(!!x, !!y), kl(!!y, !!x))
   })
 })
 
@@ -214,11 +239,11 @@ test_that("tv(x,y) is symmetric", {
   replicate(10, {
     x <- runif(10)
     x <- x / sum(x)
-    
+
     y <- runif(10)
     y <- y / sum(y)
-    
-    expect_equal(tv(!!x,!!y), tv(!!y,!!x))
+
+    expect_equal(tv(!!x, !!y), tv(!!y, !!x))
   })
 })
 
@@ -226,11 +251,11 @@ test_that("hl(x,y) is symmetric", {
   replicate(10, {
     x <- runif(10)
     x <- x / sum(x)
-    
+
     y <- runif(10)
     y <- y / sum(y)
-    
-    expect_equal(hl(!!x,!!y), hl(!!y,!!x))
+
+    expect_equal(hl(!!x, !!y), hl(!!y, !!x))
   })
 })
 
@@ -238,10 +263,42 @@ test_that("bh(x,y) is symmetric", {
   replicate(10, {
     x <- runif(10)
     x <- x / sum(x)
-    
+
     y <- runif(10)
     y <- y / sum(y)
-    
+
     expect_equal(bh(!!x, !!y), bh(!!y, !!x))
   })
 })
+
+
+############## 
+
+
+test_that("generate_xor_dataset", {
+  DD <- generate_xor_dataset(n = 5, N = 99)
+  expect_equal(dim(DD), c(99,6))
+  expect_equal(colnames(DD)[6], "C")
+})
+
+test_that("generate_linear_dataset", {
+  DD <- generate_linear_dataset(n = 5, N = 99)
+  expect_equal(dim(DD), c(99,6))
+  expect_equal(colnames(DD)[6], "C")
+})
+
+test_that("generate_random_dataset", {
+  DD <- generate_random_dataset(n = 5, N = 99)
+  expect_equal(dim(DD), c(99,5))
+})
+
+#####################
+
+test_that("which_class (internal)",{
+  D <- factor("D", c("A", "B", "C", "D", "E"))
+  A <- factor("A", c("A", "B", "C", "D", "E"))
+  expect_equal(stagedtrees:::which_class(c(-Inf, -10, -4, -1, -6),
+                                         c("A", "B", "C", "D", "E")), !!D)
+  expect_equal(stagedtrees:::which_class(c(-0.1, -10, -4, -1, -6),
+                                         c("A", "B", "C", "D", "E")), !!A)
+})
\ No newline at end of file
